@@ -1,8 +1,8 @@
 #' Create package data
 #'
-#' `use_data()` makes it easy to save package data in the correct format.
-#' I recommend you save scripts that generate package data in `data-raw`:
-#' use `use_data_raw()` to set it up.
+#' `use_data()` makes it easy to save package data in the correct format. I
+#' recommend you save scripts that generate package data in `data-raw`: use
+#' `use_data_raw()` to set it up. You also need to document exported datasets.
 #'
 #' @param ... Unquoted names of existing objects to save.
 #' @param internal If `FALSE`, saves each object in its own `.rda`
@@ -21,6 +21,7 @@
 #' @param version The serialization format version to use. The default, 2, was
 #'   the default format from R 1.4.0 to 3.5.3. Version 3 became the default from
 #'   R 3.6.0 and can only be read by R versions 3.5.0 and higher.
+#' @inheritParams base::save
 #'
 #' @seealso The [data chapter](https://r-pkgs.org/data.html) of [R
 #'   Packages](https://r-pkgs.org).
@@ -37,11 +38,17 @@ use_data <- function(...,
                      internal = FALSE,
                      overwrite = FALSE,
                      compress = "bzip2",
-                     version = 2) {
+                     version = 2,
+                     ascii = FALSE) {
   check_is_package("use_data()")
 
   objs <- get_objs_from_dots(dots(...))
 
+  if (version < 3) {
+    use_dependency("R", "depends", "2.10")
+  } else {
+    use_dependency("R", "depends", "3.5")
+  }
   if (internal) {
     use_directory("R")
     paths <- path("R", "sysdata.rda")
@@ -49,17 +56,26 @@ use_data <- function(...,
   } else {
     use_directory("data")
     paths <- path("data", objs, ext = "rda")
+    desc <- proj_desc()
+
+    if (!desc$has_fields("LazyData")) {
+      ui_done("Setting {ui_field('LazyData')} to \\
+              {ui_value('true')} in {ui_path('DESCRIPTION')}")
+      desc$set(LazyData = "true")
+      desc$write()
+    }
   }
   check_files_absent(proj_path(paths), overwrite = overwrite)
 
   ui_done("Saving {ui_value(unlist(objs))} to {ui_value(paths)}")
+  if (!internal) ui_todo("Document your data (see {ui_value('https://r-pkgs.org/data.html')})")
 
   envir <- parent.frame()
   mapply(
     save,
     list = objs,
     file = proj_path(paths),
-    MoreArgs = list(envir = envir, compress = compress, version = version)
+    MoreArgs = list(envir = envir, compress = compress, version = version, ascii = ascii)
   )
 
   invisible()
@@ -111,8 +127,8 @@ check_files_absent <- function(paths, overwrite) {
 #' \dontrun{
 #' use_data_raw("daisy")
 #' }
-use_data_raw <- function(name = "DATASET", open = interactive()) {
-  stopifnot(is_string(name))
+use_data_raw <- function(name = "DATASET", open = rlang::is_interactive()) {
+  check_name(name)
   r_path <- path("data-raw", asciify(name), ext = "R")
   use_directory("data-raw", ignore = TRUE)
 
