@@ -3,6 +3,18 @@ can_overwrite <- function(path) {
     return(TRUE)
   }
 
+  if (getOption("usethis.overwrite", FALSE)) {
+    # don't activate a project
+    # don't assume `path` is in the active project
+    if (is_in_proj(path) && uses_git()) {      # path is in active project
+      return(TRUE)
+    }
+    if (possibly_in_proj(path) &&              # path is some other project
+        with_project(proj_find(path), uses_git(), quiet = TRUE)) {
+      return(TRUE)
+    }
+  }
+
   if (is_interactive()) {
     ui_yeah("Overwrite pre-existing file {ui_path(path)}?")
   } else {
@@ -28,17 +40,10 @@ dots <- function(...) {
 }
 
 asciify <- function(x) {
-  stopifnot(is.character(x))
+  check_character(x)
   gsub("[^a-zA-Z0-9_-]+", "-", x)
 }
 
-slug <- function(x, ext) {
-  x_base <- path_ext_remove(x)
-  x_ext <- path_ext(x)
-  ext <- if (identical(tolower(x_ext), tolower(ext))) x_ext else ext
-  as.character(path_ext_set(x_base, ext))
-}
-
 compact <- function(x) {
   is_empty <- vapply(x, function(x) length(x) == 0, logical(1))
   x[!is_empty]
@@ -48,22 +53,6 @@ compact <- function(x) {
 is_installed <- function(pkg) {
   rlang::is_installed(pkg)
 }
-check_installed <- function(pkg) {
-  rlang::check_installed(pkg)
-}
-
-interactive <- function() {
-  ui_stop(
-    "Internal error: use rlang's {ui_code('is_interactive()')} \\
-     instead of {ui_code('base::interactive()')}"
-  )
-}
-
-on.exit <- function(...) {
-  ui_stop("
-    Internal error: use withr's {ui_code('defer()')} and friends, \\
-    instead of {ui_code('base::on.exit()')}")
-}
 
 isFALSE <- function(x) {
   identical(x, FALSE)
@@ -73,9 +62,10 @@ isNA <- function(x) {
   length(x) == 1 && is.na(x)
 }
 
-path_first_existing <- function(...) {
-  paths <- path(...)
-  for (path in paths) {
+path_first_existing <- function(paths) {
+  # manual loop with explicit use of `[[` to retain "fs" class
+  for (i in seq_along(paths)) {
+    path <- paths[[i]]
     if (file_exists(path)) {
       return(path)
     }
@@ -85,23 +75,37 @@ path_first_existing <- function(...) {
 }
 
 is_online <- function(host) {
-  !is.null(curl::nslookup(host, error = FALSE))
+  bare_host <- sub("^https?://(.*)$", "\\1", host)
+  !is.null(curl::nslookup(bare_host, error = FALSE))
 }
 
 year <- function() format(Sys.Date(), "%Y")
 
 pluck_lgl <- function(.x, ...) {
-  as_logical(purrr::pluck(.x, ..., .default = NA))
+  as.logical(purrr::pluck(.x, ..., .default = NA))
 }
 
 pluck_chr <- function(.x, ...) {
-  as_character(purrr::pluck(.x, ..., .default = NA))
+  as.character(purrr::pluck(.x, ..., .default = NA))
 }
 
 pluck_int <- function(.x, ...) {
-  as_integer(purrr::pluck(.x, ..., .default = NA))
+  as.integer(purrr::pluck(.x, ..., .default = NA))
 }
 
 is_windows <- function() {
   .Platform$OS.type == "windows"
 }
+
+# For stability of `stringsAsFactors` across versions
+data.frame <- function(..., stringsAsFactors = FALSE) {
+  base::data.frame(..., stringsAsFactors = stringsAsFactors)
+}
+
+# wrapper around check_name() from import-standalone-types-check.R
+# for the common case when NULL is allowed (often default)
+maybe_name <- function(x, ..., arg = caller_arg(x),
+                       call = caller_env()) {
+  check_name(x, ..., allow_null = TRUE,
+             arg = arg, call = call)
+}
