@@ -4,7 +4,7 @@ test_that("use_tibble() requires a package", {
 })
 
 test_that("use_tibble() Imports tibble", {
-  create_local_package(path_temp("mypackage"))
+  create_local_package()
 
   withr::local_options(list(usethis.quiet = FALSE))
   local_roxygen_update_ns()
@@ -12,7 +12,10 @@ test_that("use_tibble() Imports tibble", {
   ui_silence(use_package_doc())
   local_check_fun_exists()
 
-  expect_snapshot(use_tibble())
+  expect_snapshot(
+    use_tibble(),
+    transform = scrub_testpkg
+  )
 
   expect_match(proj_desc()$get("Imports"), "tibble")
 })
